import pandas as pd
import io
import os
from .sazPure import updated_nm, make_report

def make_csv(dfrm, file_name, file_path=None):
    dest = os.path.join(file_path, file_name)
    dfrm.to_csv(dest, index=False, encoding='utf-8')

def tbl_schema(dfrm):
    dfrm = pd.DataFrame(dfrm)
    buffer = io.StringIO()
    dfrm.info(buf=buffer)
    schema = buffer.getvalue()
    f_name = updated_nm('schema', 'txt')
    make_report(f_name, schema)

def tbl_cardin(dfrm):
    cardins = 'This is the cardinality report of table. \n\n'
    for col in dfrm.columns:
        cardin = dfrm[col].value_counts().to_string()
        cardins += f'The cardinality of *{col}* is:\n{cardin}\n'
    print(cardins)
    f_name = updated_nm('cardinality', 'txt')
    make_report(f_name, cardins)


import os
from datetime import date
import pandas as pd

def updated_nm(initial, frmt):
    today = date.today()
    tdyfrmt = today.strftime('%Y%m%d')
    return f"{initial}_report_{tdyfrmt}.{frmt}"

def make_report(file_name, content):
    with open(file_name, "w", encoding="utf-8") as f:
        f.write(content)

def remove_quotes(file_path, output_path):
    try:
        df = pd.read_csv(file_path, dtype=str)

        df.columns = [col.replace('"', '').replace("'", '') for col in df.columns]
        df = df.apply(lambda col: col.str.replace('"', '').str.replace("'", '') if col.dtype == "object" else col)

        df.to_csv(output_path, index=False)

        if os.path.exists(output_path):
            print(f"✅ Cleaned CSV saved to: {output_path}")
        else:
            print(f"⚠️ CSV not saved. Check permissions or path: {output_path}")

        return df
    except Exception as e:
        print(f"❌ Error: {e}")
        return None


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="saz",
    version="0.1.01",  # 🔁 MUST BUMP VERSION for PyPI upload
    packages=["saz"],
    license="MIT",
    description="Tools for CSV cleaning and reporting",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Saman Siadati",
    author_email="siadatisaman@gmail.com",
    url="https://github.com/samansiadati/saz",
    project_urls={
        "Bug Tracker": "https://github.com/samansiadati/saz/issues",
    },
    install_requires=["pandas"],
    keywords=["pandas", "csv", "data cleaning", "reporting", "saz"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
)